@@ -1,8 +1,6 @@
 package Alien::Kiwisolver;
 # ABSTRACT: Alien package for the Kiwi C++ implementation of the Cassowary constraint solving algorithm
-$Alien::Kiwisolver::VERSION = '0.002_003'; # TRIAL
-
-$Alien::Kiwisolver::VERSION = '0.002003';
+$Alien::Kiwisolver::VERSION = '0.001';
 use strict;
 use warnings;
 
@@ -18,18 +16,12 @@ sub Inline {
 	if( $lang =~ /^CPP$/ ) {
 		my $params = Alien::Base::Inline(@_);
 
-		$params->{CCFLAGSEX} = $self->runtime_prop->{cppstdflag};
+		$params->{CCFLAGSEX} = '-std=c++11';
 
 		$params->{PRE_HEAD} = <<'		EOF';
 		#if defined(_MSC_VER) || defined(__MINGW32__)
 		#  define NO_XSLOCKS /* To avoid Perl wrappers of C library */
 		#endif
-
-		#ifdef __cplusplus
-			// Avoid Perl's "seed" macro that breaks <algorithm> by including <algorithm> first.
-			#include <algorithm>
-		#endif
-
 		EOF
 
 		return $params;
@@ -51,7 +43,7 @@ Alien::Kiwisolver - Alien package for the Kiwi C++ implementation of the Cassowa
 
 =head1 VERSION
 
-version 0.002_003
+version 0.001
 
 =head1 Inline support
 
